@@ -4,7 +4,7 @@
 #' Abstract R6 Class that encapsulates all the operations needed by
 #' Shiny.telemetry to read and write. This removes the complexity from the
 #' functions and uses a unified API.
-DataStorage <- R6::R6Class( # nolint object_name_linter
+DataStorage <- R6::R6Class( # nolint object_name.
   classname = "DataStorage",
   public = list(
 
@@ -63,11 +63,11 @@ DataStorage <- R6::R6Class( # nolint object_name_linter
       #  :: (id, value, username)
       db_data %>%
         dplyr::bind_rows(dplyr::tibble(
-          time = as.POSIXct(character(0)),
-          date = as.Date(character(0)),
-          id = character(0),
-          value = character(0),
-          username = character(0)
+          time = as.POSIXct(character(0L)),
+          date = as.Date(character(0L)),
+          id = character(0L),
+          value = character(0L),
+          username = character(0L)
         ))
     },
 
